@@ -1,6 +1,5 @@
 mod args;
 mod format;
-mod framebuff;
 mod sampl_pool;
 mod sampler;
 mod tex_type;
@@ -16,4 +15,4 @@ pub mod spec {
 	pub use super::format::{TexFmt, TexSize};
 	pub use super::tex_type::*;
 }
-pub use {framebuff::*, sampl_pool::*, sampler::*, texbuff::*, texture::*};
+pub use {sampl_pool::*, sampler::*, texbuff::*, texture::*};
