@@ -1,10 +1,9 @@
 mod animation;
 mod atlas;
 mod atlas_pack;
-mod fbo;
 mod img;
 mod serialize;
 mod tex_to_img;
 mod vtex;
 
-pub use {animation::*, atlas::*, fbo::*, img::*, vtex::*};
+pub use {animation::*, atlas::*, img::*, vtex::*};
